# Programme de test des commandes AT
# framboise314 le 19 janvier 2024
# d'après https://khunsomsak.medium.com/elecrow-lora-ra-08h-node-board-%E0%B8%81%E0%B8%B1%E0%B8%9A-micropython-90ad1bb6058d

from machine import UART
from machine import ADC, Pin
import time
from time import sleep
import dht

# Pin du DHT11

capteur = dht.DHT11(Pin(2))

# Pin du capteur de lumière A1

adc = ADC(0)

# Communication avec le Ra-08H

uart = UART(0, 9600,timeout=1000)
rstr=""    
def sendATcommand(ATcommand):
    print("Command: {0}\r\n".format(ATcommand))
    uart.write("{0}\r\n".format(ATcommand))
    rstr=uart.read().decode('utf-8')
    print(rstr)
    return (rstr)

# Configurer le module pour TTN
# Remplacer par vos valeurs
sendATcommand ("AT+CDEVEUI=70Bxxxxxxxxxx2C")
sendATcommand ("AT+CAPPKEY=C12xxxxxxxxxxxxxxxxxxxxxxxxx302")
sendATcommand ("AT+CAPPEUI=0016xxxxxxxxxxx56")

# Relire les infos pour confirmer l'écriture
# On peut supprimer quand on est certain que tout fonctionne

sendATcommand ("AT+CDEVEUI?")
sendATcommand ("AT+CAPPKEY?")
sendATcommand ("AT+CAPPEUI?")

# Se connecter à TTN

sendATcommand ("AT+CJOIN=1,0,8,1")
time.sleep(15.0)
rstr=sendATcommand ('AT+CSTATUS?')
print('\n++++++++++++++++++++')
print('Res='+rstr)
print('\n++++++++++++++++++++')

# Continuer les tentatives de connexions si pas connecté
# Le while ne sert pas si on se connecte ci-dessus

while '+CSTATUS:04' not in rstr:
        print('Retry OTAA Continue')
        sendATcommand ('AT+CJOIN=1,0,8,2')
        time.sleep(20)
        rstr=sendATcommand ('AT+CSTATUS?')
        print('################ Chaine réponse')
        print(rstr)
        if '+CSTATUS:04' in rstr:
            print('\n++++ OTAA OK +++++')
            break
        

# Si on est connecté : envoyer la trame 

count=1
while True:
    try:
        sleep(1)
        # Le DHT11 renvoie au maximum une mesure toute les 1s
        # Comme sa précision est de 1° on ne prend pas en compte les chiffres après la virgule
        # mais le programme est prêt si vous utilisez un capteur plus précis
        capteur.measure()
        # Récupère les mesures du capteur et les affiche
        temp = capteur.temperature()
        hum = capteur.humidity()

        # Transmet la température sur la console de l'ordinateur
        print(f"Temperature : {temp:.1f}")
        print(f"Humidite    : {hum:.1f}")
    except OSError as e:
        print('Echec reception')
        # Si la pico ne reçoit pas les mesures du capteur
  
    # Convertir la température en hexadécimal sur 2 octets
    temp_hex = "{:04x}".format(temp*10)

    # Afficher la température en hexadécimal
    print("Température en hexadécimal : 0x{}".format(temp_hex))

    # Convertir l'humidité en hexadécimal sur 1 octets
    hum_hex = "{:02x}".format(hum)
    
    # Afficher la chaine hexadécimale
    print("Humidité en hexadécimal : 0x{}".format(hum_hex))
   
    # Lire le port ADC lumière
    lum = adc.read_u16()
    print("Lumière mesurée : ", lum)
        
    # Convertir la lumière en chaien hexa
    lum_hex = "{:04x}".format(lum)
 
    # Créer la chaine à envoyer à la passerelle 
    chaine = hum_hex + temp_hex + lum_hex
    print (chaine)

    if '+CSTATUS:04' in rstr:
        print('\n++++OTAA OK+++++')
        ATcommand = "AT+DTRX=0,2,5," + chaine
        sendATcommand (ATcommand)
        count+=1
        print('Nombre de paquets : ', count)
        time.sleep(15)

